﻿SystemOrganization addCategory: #ConfigurationOfNagare!

Object subclass: #ConfigurationOfNagare
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfNagare'!

!ConfigurationOfNagare class methodsFor: 'private' stamp: 'mu 5/3/2012 15:00'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfNagare class methodsFor: 'development support' stamp: 'mu 5/3/2012 15:00'!
compareVersions
	"Compare previous version to development version"

	"self compareVersions"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) compareVersionsIn: self) inspect
! !

!ConfigurationOfNagare class methodsFor: 'development support' stamp: 'mu 5/3/2012 15:00'!
createNewDevelopmentVersion
	"Create a new development version using the #stable version as model."

	"self createNewDevelopmentVersion"
	
	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) createNewDevelopmentVersionIn: self description: ''! !

!ConfigurationOfNagare class methodsFor: 'private' stamp: 'mu 5/3/2012 15:00'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
			self bootstrapPackage: 'Gofer-Core-lr.115' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load 'default' group of Metacello"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #load ]! !

!ConfigurationOfNagare class methodsFor: 'metacello tool support' stamp: 'mu 5/3/2012 15:00'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfNagare class methodsFor: 'metacello tool support' stamp: 'mu 5/3/2012 15:00'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfNagare class methodsFor: 'loading' stamp: 'mu 5/3/2012 15:00'!
load
	"self load"

	^self project latestVersion load! !

!ConfigurationOfNagare class methodsFor: 'metacello tool support' stamp: 'mu 5/3/2012 15:00'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfNagare class methodsFor: 'accessing' stamp: 'mu 5/3/2012 15:00'!
project

	^self new project! !

!ConfigurationOfNagare class methodsFor: 'development support' stamp: 'mu 5/3/2012 15:00'!
updateToLatestPackageVersions: descriptionString
	"Updates mcz file versions in current version"

	"self updateToLatestPackageVersions: '- fixed a bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) updateToLatestPackageVersionsIn: self description: descriptionString) isEmpty
		ifTrue: [ self inform: 'All specs up to date' ]! !

!ConfigurationOfNagare methodsFor: 'baselines' stamp: 'mu 5/3/2012 21:56'!
baseline100: spec 
	<version: '1.0-baseline'>
	spec for: #common do: [
		spec blessing: #baseline.
		spec 
			repository: 'http://ss3.gemstone.com/ss/Nagare'.
		spec
			project: 'MessagePack Core' with: [
				spec
					className: 'ConfigurationOfMessagePack'; loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec
			project: 'StOMP Core' with: [
				spec
					className: 'ConfigurationOfStOMP'; loads: #('Core' );
					repository: 'http://www.squeaksource.com/MetacelloRepository' ].
		spec 
			package: 'Nagare-Core' with: [ spec requires: 'MessagePack Core' ].
		spec 
			package: 'NagareTest-Core' with: [ spec requires: #('Nagare-Core' 'StOMP Core') ].
		spec
			group: 'default' with: #('Core');
			group: 'Core' with: #('Nagare-Core');
			group: 'Tests' with: #('NagareTest-Core'). ].
	
	spec for: #squeakCommon do: [
		spec 
			package: 'Nagare-Core' with: [ spec includes: #('Nagare-Squeak-Core') ]. 
		spec
			group: 'Core' with: #('Nagare-Squeak-Core')]
	! !

!ConfigurationOfNagare methodsFor: 'symbolic versions' stamp: 'mu 5/3/2012 15:00'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: #notDefined.
! !

!ConfigurationOfNagare methodsFor: 'accessing' stamp: 'mu 5/3/2012 15:00'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear.
		"use atomic load on GemStone to resolve some loading issues"
		Smalltalk at: #SystemVersion ifAbsent: [ project loadType: #atomic ]. 
		project ]! !

!ConfigurationOfNagare methodsFor: 'doits' stamp: 'mu 5/3/2012 15:01'!
squeakCommonPostLoadDoIt
	Smalltalk at: #NgSqPortableUtil ifPresent: [:p | p initialize]! !

!ConfigurationOfNagare methodsFor: 'symbolic versions' stamp: 'mu 5/3/2012 15:01'!
stable: spec 
	<symbolicVersion: #stable>
	
	spec for: #'common' version: #notDefined.! !

!ConfigurationOfNagare methodsFor: 'versions' stamp: 'mu 5/4/2012 12:43'!
version100: spec 
	<version: '1.0' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #beta.
		spec author: 'Masashi Umezawa'.
		spec 
			project: 'MessagePack Core' with: '1.0.4';
			project: 'MessagePack Test' with: '1.0.4'.
		spec 
			package: 'Nagare-Core' with: 'Nagare-Core-mu.9';
			package: 'NagareTest-Core' with: 'NagareTest-Core-mu.2'].
	spec for: #squeakCommon do: [
		spec 
			package: 'Nagare-Squeak-Core' with: 'Nagare-Squeak-Core-mu.4']! !

!ConfigurationOfNagare methodsFor: 'versions' stamp: 'mu 5/4/2012 22:11'!
version101: spec 
	<version: '1.0.1' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #beta.
		spec author: 'Masashi Umezawa'.
		spec 
			project: 'MessagePack Core' with: '1.0.4';
			project: 'MessagePack Test' with: '1.0.4'.
		spec 
			package: 'Nagare-Core' with: 'Nagare-Core-mu.10';
			package: 'NagareTest-Core' with: 'NagareTest-Core-mu.3'].
	spec for: #squeakCommon do: [
		spec 
			package: 'Nagare-Squeak-Core' with: 'Nagare-Squeak-Core-mu.5']! !

!ConfigurationOfNagare methodsFor: 'versions' stamp: 'mu 5/5/2012 21:24'!
version102: spec 
	<version: '1.0.2' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #beta.
		spec author: 'Masashi Umezawa'.
		spec 
			project: 'MessagePack Core' with: '1.0.4';
			project: 'MessagePack Test' with: '1.0.4'.
		spec 
			package: 'Nagare-Core' with: 'Nagare-Core-mu.11';
			package: 'NagareTest-Core' with: 'NagareTest-Core-mu.3'].
	spec for: #squeakCommon do: [
		spec 
			package: 'Nagare-Squeak-Core' with: 'Nagare-Squeak-Core-mu.5']! !
